// LoadDLL.cpp : Made to isolate the load of the DLL
//

#include "stdafx.h"

static void* dynamicLibrary = NULL;

// Load the DarumaFramework for memory
//
void loadDarumaFramework() 
{
	char* error = NULL;
	if(!dynamicLibrary) 
	{
#ifdef WIN32
		dynamicLibrary = LoadLibrary(TEXT("DarumaFrameWork.dll"));
#else
		dynamicLibrary = dlopen("./libDarumaFramework.so", RTLD_NOW);
#endif
	}

	if (!dynamicLibrary) 
	{
#ifdef WIN32
		error = (char*) GetLastError();
#else
		error = dlerror();
#endif
		printf("Erro ao carregar a DarumaFrameWork: %s.\n", error);
		exit(EXIT_FAILURE);
	}
}

// Unload Daruma Framework of memory.
//
void unloadDarumaFramework() 
{
	char* error = NULL;
	int descarregou = 0;

	if (dynamicLibrary) 
	{
#ifdef WIN32
		descarregou = FreeLibrary((HMODULE) dynamicLibrary);
#else
		descarregou = dlclose(dynamicLibrary);
#endif
	}

	if (!descarregou) {
#ifdef WIN32
		error = (char*) GetLastError();
#else
		error = dlerror();
#endif
		printf("Erro ao descarregar a DarumaFrameWork: %s\n", error);
	}

}

// @param nameFunction function name for load memory.
// @return pointer for function or NULL;
//
void* loadFunctionDarumaFramework(const char* nameFunction) 
{
	void* function = NULL;
	char* error = NULL;

	if (!dynamicLibrary) 
	{
		loadDarumaFramework();
	}

#ifdef WIN32
	if(strcmp(nameFunction, "regAlterarValor_NFCe_Daruma") == 0){
		if(regAlterarValor_NFCe_Daruma_load == NULL) regAlterarValor_NFCe_Daruma_load = (regAlterarValor_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "regAlterarValor_NFCe_Daruma");
		function = (int*)regAlterarValor_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "regRetornarValor_NFCe_Daruma") == 0){
		if(regRetornarValor_NFCe_Daruma_load == NULL) regRetornarValor_NFCe_Daruma_load = (regRetornarValor_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "regRetornarValor_NFCe_Daruma");
		function = (int*)regRetornarValor_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "regAlterarValor_Daruma") == 0){
		if(regAlterarValor_Daruma_load == NULL) regAlterarValor_Daruma_load = (regAlterarValor_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "regAlterarValor_Daruma");
		function = (int*)regAlterarValor_Daruma_load;
	}else if(strcmp(nameFunction, "aCFAbrir_NFCe_Daruma") == 0){
		if(aCFAbrir_NFCe_Daruma_load == NULL) aCFAbrir_NFCe_Daruma_load = (aCFAbrir_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFAbrir_NFCe_Daruma");
		function = (int*)aCFAbrir_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFAbrirNumSerie_NFCe_Daruma") == 0){
		if(aCFAbrirNumSerie_NFCe_Daruma_load == NULL) aCFAbrirNumSerie_NFCe_Daruma_load = (aCFAbrirNumSerie_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFAbrirNumSerie_NFCe_Daruma");
		function = (int*)aCFAbrirNumSerie_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfImposto_NFCe_Daruma") == 0){
		if(aCFConfImposto_NFCe_Daruma_load == NULL) aCFConfImposto_NFCe_Daruma_load = (aCFConfImposto_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfImposto_NFCe_Daruma");
		function = (int*)aCFConfImposto_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfRastro_NFCe_Daruma") == 0){
		if(aCFConfRastro_NFCe_Daruma_load == NULL) aCFConfRastro_NFCe_Daruma_load = (aCFConfRastro_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfRastro_NFCe_Daruma");
		function = (int*)aCFConfRastro_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMS00_NFCe_Daruma") == 0){
		if(aCFConfICMS00_NFCe_Daruma_load == NULL) aCFConfICMS00_NFCe_Daruma_load = (aCFConfICMS00_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfICMS00_NFCe_Daruma");
		function = (int*)aCFConfICMS00_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMS20_NFCe_Daruma") == 0){
		if(aCFConfICMS20_NFCe_Daruma_load == NULL) aCFConfICMS20_NFCe_Daruma_load = (aCFConfICMS20_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfICMS20_NFCe_Daruma");
		function = (int*)aCFConfICMS20_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMS40_NFCe_Daruma") == 0){
		if(aCFConfICMS40_NFCe_Daruma_load == NULL) aCFConfICMS40_NFCe_Daruma_load = (aCFConfICMS40_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfICMS40_NFCe_Daruma");
		function = (int*)aCFConfICMS40_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMS60_NFCe_Daruma") == 0){
		if(aCFConfICMS60_NFCe_Daruma_load == NULL) aCFConfICMS60_NFCe_Daruma_load = (aCFConfICMS60_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfICMS60_NFCe_Daruma");
		function = (int*)aCFConfICMS60_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMS90_NFCe_Daruma") == 0){
		if(aCFConfICMS90_NFCe_Daruma_load == NULL) aCFConfICMS90_NFCe_Daruma_load = (aCFConfICMS90_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfICMS90_NFCe_Daruma");
		function = (int*)aCFConfICMS90_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMSSN102_NFCe_Daruma") == 0){
		if(aCFConfICMSSN102_NFCe_Daruma_load == NULL) aCFConfICMSSN102_NFCe_Daruma_load = (aCFConfICMSSN102_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfICMSSN102_NFCe_Daruma");
		function = (int*)aCFConfICMSSN102_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMSSN500_NFCe_Daruma") == 0){
		if(aCFConfICMSSN500_NFCe_Daruma_load == NULL) aCFConfICMSSN500_NFCe_Daruma_load = (aCFConfICMSSN500_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfICMSSN500_NFCe_Daruma");
		function = (int*)aCFConfICMSSN500_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMSSN900_NFCe_Daruma") == 0){
		if(aCFConfICMSSN900_NFCe_Daruma_load == NULL) aCFConfICMSSN900_NFCe_Daruma_load = (aCFConfICMSSN900_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfICMSSN900_NFCe_Daruma");
		function = (int*)aCFConfICMSSN900_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfPisAliq_NFCe_Daruma") == 0){
		if(aCFConfPisAliq_NFCe_Daruma_load == NULL) aCFConfPisAliq_NFCe_Daruma_load = (aCFConfPisAliq_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfPisAliq_NFCe_Daruma");
		function = (int*)aCFConfPisAliq_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfPisQtde_NFCe_Daruma") == 0){
		if(aCFConfPisQtde_NFCe_Daruma_load == NULL) aCFConfPisQtde_NFCe_Daruma_load = (aCFConfPisQtde_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfPisQtde_NFCe_Daruma");
		function = (int*)aCFConfPisQtde_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfPisNT_NFCe_Daruma") == 0){
		if(aCFConfPisNT_NFCe_Daruma_load == NULL) aCFConfPisNT_NFCe_Daruma_load = (aCFConfPisNT_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfPisNT_NFCe_Daruma");
		function = (int*)aCFConfPisNT_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfPisOutr_NFCe_Daruma") == 0){
		if(aCFConfPisOutr_NFCe_Daruma_load == NULL) aCFConfPisOutr_NFCe_Daruma_load = (aCFConfPisOutr_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfPisOutr_NFCe_Daruma");
		function = (int*)aCFConfPisOutr_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfCofinsAliq_NFCe_Daruma") == 0){
		if(aCFConfCofinsAliq_NFCe_Daruma_load == NULL) aCFConfCofinsAliq_NFCe_Daruma_load = (aCFConfCofinsAliq_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfCofinsAliq_NFCe_Daruma");
		function = (int*)aCFConfCofinsAliq_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfCofinsQtde_NFCe_Daruma") == 0){
		if(aCFConfCofinsQtde_NFCe_Daruma_load == NULL) aCFConfCofinsQtde_NFCe_Daruma_load = (aCFConfCofinsQtde_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfCofinsQtde_NFCe_Daruma");
		function = (int*)aCFConfCofinsQtde_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfCofinsNT_NFCe_Daruma") == 0){
		if(aCFConfCofinsNT_NFCe_Daruma_load == NULL) aCFConfCofinsNT_NFCe_Daruma_load = (aCFConfCofinsNT_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfCofinsNT_NFCe_Daruma");
		function = (int*)aCFConfCofinsNT_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfCofinsOutr_NFCe_Daruma") == 0){
		if(aCFConfCofinsOutr_NFCe_Daruma_load == NULL) aCFConfCofinsOutr_NFCe_Daruma_load = (aCFConfCofinsOutr_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfCofinsOutr_NFCe_Daruma");
		function = (int*)aCFConfCofinsOutr_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFValorLeiImposto_NFCe_Daruma") == 0){
		if(aCFValorLeiImposto_NFCe_Daruma_load == NULL) aCFValorLeiImposto_NFCe_Daruma_load = (aCFValorLeiImposto_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFValorLeiImposto_NFCe_Daruma");
		function = (int*)aCFValorLeiImposto_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfLeiImposto_NFCe_Daruma") == 0){
		if(aCFConfLeiImposto_NFCe_Daruma_load == NULL) aCFConfLeiImposto_NFCe_Daruma_load = (aCFConfLeiImposto_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfLeiImposto_NFCe_Daruma");
		function = (int*)aCFConfLeiImposto_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfCombustivel_NFCe_Daruma") == 0){
		if(aCFConfCombustivel_NFCe_Daruma_load == NULL) aCFConfCombustivel_NFCe_Daruma_load = (aCFConfCombustivel_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFConfCombustivel_NFCe_Daruma");
		function = (int*)aCFConfCombustivel_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFVender_NFCe_Daruma") == 0){
		if(aCFVender_NFCe_Daruma_load == NULL) aCFVender_NFCe_Daruma_load = (aCFVender_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFVender_NFCe_Daruma");
		function = (int*)aCFVender_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFVenderCompleto_NFCe_Daruma") == 0){
		if(aCFVenderCompleto_NFCe_Daruma_load == NULL) aCFVenderCompleto_NFCe_Daruma_load = (aCFVenderCompleto_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFVenderCompleto_NFCe_Daruma");
		function = (int*)aCFVenderCompleto_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFVenderXml_NFCe_Daruma") == 0){
		if(aCFVenderXml_NFCe_Daruma_load == NULL) aCFVenderXml_NFCe_Daruma_load = (aCFVenderXml_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFVenderXml_NFCe_Daruma");
		function = (int*)aCFVenderXml_NFCe_Daruma_load;
    }else if(strcmp(nameFunction, "aCFLancarAcrescimoItem_NFCe_Daruma") == 0){
		if(aCFLancarAcrescimoItem_NFCe_Daruma_load == NULL) aCFLancarAcrescimoItem_NFCe_Daruma_load = (aCFLancarAcrescimoItem_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFLancarAcrescimoItem_NFCe_Daruma");
		function = (int*)aCFLancarAcrescimoItem_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFLancarDescontoItem_NFCe_Daruma") == 0){
		if(aCFLancarDescontoItem_NFCe_Daruma_load == NULL) aCFLancarDescontoItem_NFCe_Daruma_load = (aCFLancarDescontoItem_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFLancarDescontoItem_NFCe_Daruma");
		function = (int*)aCFLancarDescontoItem_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFCancelarAcrescimoItem_NFCe_Daruma") == 0){
		if(aCFCancelarAcrescimoItem_NFCe_Daruma_load == NULL) aCFCancelarAcrescimoItem_NFCe_Daruma_load = (aCFCancelarAcrescimoItem_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFCancelarAcrescimoItem_NFCe_Daruma");
		function = (int*)aCFCancelarAcrescimoItem_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFCancelarDescontoItem_NFCe_Daruma") == 0){
		if(aCFCancelarDescontoItem_NFCe_Daruma_load == NULL) aCFCancelarDescontoItem_NFCe_Daruma_load = (aCFCancelarDescontoItem_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFCancelarDescontoItem_NFCe_Daruma");
		function = (int*)aCFCancelarDescontoItem_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFCancelarItemParcial_NFCe_Daruma") == 0){
		if(aCFCancelarItemParcial_NFCe_Daruma_load == NULL) aCFCancelarItemParcial_NFCe_Daruma_load = (aCFCancelarItemParcial_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFCancelarItemParcial_NFCe_Daruma");
		function = (int*)aCFCancelarItemParcial_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFCancelarItem_NFCe_Daruma") == 0){
		if(aCFCancelarItem_NFCe_Daruma_load == NULL) aCFCancelarItem_NFCe_Daruma_load = (aCFCancelarItem_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFCancelarItem_NFCe_Daruma");
		function = (int*)aCFCancelarItem_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFTotalizar_NFCe_Daruma") == 0){
		if(aCFTotalizar_NFCe_Daruma_load == NULL) aCFTotalizar_NFCe_Daruma_load = (aCFTotalizar_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFTotalizar_NFCe_Daruma");
		function = (int*)aCFTotalizar_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFIdentificarCartao_NFCe_Daruma") == 0){
		if(aCFIdentificarCartao_NFCe_Daruma_load == NULL) aCFIdentificarCartao_NFCe_Daruma_load = (aCFIdentificarCartao_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFIdentificarCartao_NFCe_Daruma");
		function = (int*)aCFIdentificarCartao_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFEfetuarPagamento_NFCe_Daruma") == 0){
		if(aCFEfetuarPagamento_NFCe_Daruma_load == NULL) aCFEfetuarPagamento_NFCe_Daruma_load = (aCFEfetuarPagamento_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFEfetuarPagamento_NFCe_Daruma");
		function = (int*)aCFEfetuarPagamento_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFEfetuarPagamentoCartao_NFCe_Daruma") == 0){
		if(aCFEfetuarPagamentoCartao_NFCe_Daruma_load == NULL) aCFEfetuarPagamentoCartao_NFCe_Daruma_load = (aCFEfetuarPagamentoCartao_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFEfetuarPagamentoCartao_NFCe_Daruma");
		function = (int*)aCFEfetuarPagamentoCartao_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFEstornarPagamento_NFCe_Daruma") == 0){
		if(aCFEstornarPagamento_NFCe_Daruma_load == NULL) aCFEstornarPagamento_NFCe_Daruma_load = (aCFEstornarPagamento_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFEstornarPagamento_NFCe_Daruma");
		function = (int*)aCFEstornarPagamento_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFIdentificarConsumidor_NFCe_Daruma") == 0){
		if(aCFIdentificarConsumidor_NFCe_Daruma_load == NULL) aCFIdentificarConsumidor_NFCe_Daruma_load = (aCFIdentificarConsumidor_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFIdentificarConsumidor_NFCe_Daruma");
		function = (int*)aCFIdentificarConsumidor_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFIdentificarTransportadora_NFCe_Daruma") == 0){
		if(aCFIdentificarTransportadora_NFCe_Daruma_load == NULL) aCFIdentificarTransportadora_NFCe_Daruma_load = (aCFIdentificarTransportadora_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFIdentificarTransportadora_NFCe_Daruma");
		function = (int*)aCFIdentificarTransportadora_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFMsgPromocional_NFCe_Daruma")==0){
		if(aCFMsgPromocional_NFCe_Daruma_load == NULL) aCFMsgPromocional_NFCe_Daruma_load = (aCFMsgPromocional_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "aCFMsgPromocional_NFCe_Daruma");
		function = (int*)aCFMsgPromocional_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tCFEncerrar_NFCe_Daruma") == 0){
		if(tCFEncerrar_NFCe_Daruma_load == NULL) tCFEncerrar_NFCe_Daruma_load = (tCFEncerrar_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tCFEncerrar_NFCe_Daruma");
		function = (int*)tCFEncerrar_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tCFEncerrarConfigMsg_NFCe_Daruma") == 0){
		if(tCFEncerrarConfigMsg_NFCe_Daruma_load == NULL) tCFEncerrarConfigMsg_NFCe_Daruma_load = (tCFEncerrarConfigMsg_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tCFEncerrarConfigMsg_NFCe_Daruma");
		function = (int*)tCFEncerrarConfigMsg_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tCFCancelar_NFCe_Daruma") == 0){
		if(tCFCancelar_NFCe_Daruma_load == NULL) tCFCancelar_NFCe_Daruma_load = (tCFCancelar_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tCFCancelar_NFCe_Daruma");
		function = (int*)tCFCancelar_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tCFCancelarParametrizado_NFCe_Daruma") == 0){
		if(tCFCancelarParametrizado_NFCe_Daruma_load == NULL) tCFCancelarParametrizado_NFCe_Daruma_load = (tCFCancelarParametrizado_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tCFCancelarParametrizado_NFCe_Daruma");
		function = (int*)tCFCancelarParametrizado_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tCFInutilizar_NFCe_Daruma") == 0){
		if(tCFInutilizar_NFCe_Daruma_load == NULL) tCFInutilizar_NFCe_Daruma_load = (tCFInutilizar_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tCFInutilizar_NFCe_Daruma");
		function = (int*)tCFInutilizar_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tDescartarNota_NFCe_Daruma") == 0){
		if(tDescartarNota_NFCe_Daruma_load == NULL) tDescartarNota_NFCe_Daruma_load = (tDescartarNota_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tDescartarNota_NFCe_Daruma");
		function = (int*)tDescartarNota_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "iCFImprimir_NFCe_Daruma") == 0){
		if(iCFImprimir_NFCe_Daruma_load == NULL) iCFImprimir_NFCe_Daruma_load = (iCFImprimir_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "iCFImprimir_NFCe_Daruma");
		function = (int*)iCFImprimir_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "iCFImprimirParametrizado_NFCe_Daruma") == 0){
		if(iCFImprimirParametrizado_NFCe_Daruma_load == NULL) iCFImprimirParametrizado_NFCe_Daruma_load = (iCFImprimirParametrizado_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "iCFImprimirParametrizado_NFCe_Daruma");
		function = (int*)iCFImprimirParametrizado_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "iCFReImprimir_NFCe_Daruma") == 0){
		if(iCFReImprimir_NFCe_Daruma_load == NULL) iCFReImprimir_NFCe_Daruma_load = (iCFReImprimir_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "iCFReImprimir_NFCe_Daruma");
		function = (int*)iCFReImprimir_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "iTEFImprimirResposta_NFCe_Daruma") == 0){
		if(iTEFImprimirResposta_NFCe_Daruma_load == NULL) iTEFImprimirResposta_NFCe_Daruma_load = (iTEFImprimirResposta_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "iTEFImprimirResposta_NFCe_Daruma");
		function = (int*)iTEFImprimirResposta_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "eAtualizarEnviarXML_NFCe_Daruma") == 0){
		if(eAtualizarEnviarXML_NFCe_Daruma_load == NULL) eAtualizarEnviarXML_NFCe_Daruma_load = (eAtualizarEnviarXML_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "eAtualizarEnviarXML_NFCe_Daruma");
		function = (int*)eAtualizarEnviarXML_NFCe_Daruma_load;
	}else if (strcmp(nameFunction, "eEmiteOffline_NFCe_Daruma") == 0){
		if(eEmiteOffline_NFCe_Daruma_load==NULL) eEmiteOffline_NFCe_Daruma_load = (eEmiteOffline_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "eEmiteOffline_NFCe_Daruma");
		function = (int*)eEmiteOffline_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "eAjustarDataHora_NFCe_Daruma") == 0){
		if(eAjustarDataHora_NFCe_Daruma_load == NULL) eAjustarDataHora_NFCe_Daruma_load = (eAjustarDataHora_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "eAjustarDataHora_NFCe_Daruma");
		function = (int*)eAjustarDataHora_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tCFCancelarOffline_NFCe_Daruma") == 0){
		if(tCFCancelarOffline_NFCe_Daruma_load == NULL) tCFCancelarOffline_NFCe_Daruma_load = (tCFCancelarOffline_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tCFCancelarOffline_NFCe_Daruma");
		function = (int*)tCFCancelarOffline_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tEnviarContingenciaOffline_NFCe_Daruma") == 0){
		if(tEnviarContingenciaOffline_NFCe_Daruma_load == NULL) tEnviarContingenciaOffline_NFCe_Daruma_load = (tEnviarContingenciaOffline_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tEnviarContingenciaOffline_NFCe_Daruma");
		function = (int*)tEnviarContingenciaOffline_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tEnviarContingenciaCancOffline_NFCe_Daruma") == 0){
		if(tEnviarContingenciaCancOffline_NFCe_Daruma_load == NULL) tEnviarContingenciaCancOffline_NFCe_Daruma_load = (tEnviarContingenciaCancOffline_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tEnviarContingenciaCancOffline_NFCe_Daruma");
		function = (int*)tEnviarContingenciaCancOffline_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rNumDocsContingencia_NFCe_Daruma") == 0){
		if(rNumDocsContingencia_NFCe_Daruma_load == NULL) rNumDocsContingencia_NFCe_Daruma_load = (rNumDocsContingencia_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rNumDocsContingencia_NFCe_Daruma");
		function = (int*)rNumDocsContingencia_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rNumDocsContingenciaCanc_NFCe_Daruma") == 0){
		if(rNumDocsContingenciaCanc_NFCe_Daruma_load == NULL) rNumDocsContingenciaCanc_NFCe_Daruma_load = (rNumDocsContingenciaCanc_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rNumDocsContingenciaCanc_NFCe_Daruma");
		function = (int*)rNumDocsContingenciaCanc_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rRetornarInformacaoContingencia_NFCe_Daruma") == 0){
		if(rRetornarInformacaoContingencia_NFCe_Daruma_load == NULL) rRetornarInformacaoContingencia_NFCe_Daruma_load = (rRetornarInformacaoContingencia_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rRetornarInformacaoContingencia_NFCe_Daruma");
		function = (int*)rRetornarInformacaoContingencia_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tEnvioUnitContingenciaOffline_NFCe_Daruma") == 0){
		if(tEnvioUnitContingenciaOffline_NFCe_Daruma_load == NULL) tEnvioUnitContingenciaOffline_NFCe_Daruma_load = (tEnvioUnitContingenciaOffline_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tEnvioUnitContingenciaOffline_NFCe_Daruma");
		function = (int*)tEnvioUnitContingenciaOffline_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tEnvioUnitContingenciaCancOffline_NFCe_Daruma") == 0){
		if(tEnvioUnitContingenciaCancOffline_NFCe_Daruma_load == NULL) tEnvioUnitContingenciaCancOffline_NFCe_Daruma_load = (tEnvioUnitContingenciaCancOffline_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tEnvioUnitContingenciaCancOffline_NFCe_Daruma");
		function = (int*)tEnvioUnitContingenciaCancOffline_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rUltimaCtg_NFCe_Daruma") == 0){
		if(rUltimaCtg_NFCe_Daruma_load == NULL) rUltimaCtg_NFCe_Daruma_load = (rUltimaCtg_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rUltimaCtg_NFCe_Daruma");
		function = (int*)rUltimaCtg_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tEnvioUnitCtg_NFCe_Daruma") == 0){
		if(tEnvioUnitCtg_NFCe_Daruma_load == NULL) tEnvioUnitCtg_NFCe_Daruma_load = (tEnvioUnitCtg_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tEnvioUnitCtg_NFCe_Daruma");
		function = (int*)tEnvioUnitCtg_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tTransacaoAdministrativaTEF_NFCe_Daruma") == 0){
		if(tTransacaoAdministrativaTEF_NFCe_Daruma_load == NULL) tTransacaoAdministrativaTEF_NFCe_Daruma_load = (tTransacaoAdministrativaTEF_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tTransacaoAdministrativaTEF_NFCe_Daruma");
		function = (int*)tTransacaoAdministrativaTEF_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tTransacaoCancelamentoTEF_NFCe_Daruma") == 0){
		if(tTransacaoCancelamentoTEF_NFCe_Daruma_load == NULL) tTransacaoCancelamentoTEF_NFCe_Daruma_load = (tTransacaoCancelamentoTEF_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tTransacaoCancelamentoTEF_NFCe_Daruma");
		function = (int*)tTransacaoCancelamentoTEF_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tEnviar_NFe_Daruma") == 0){
		if(tEnviar_NFe_Daruma_load == NULL) tEnviar_NFe_Daruma_load = (tEnviar_NFe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "tEnviar_NFe_Daruma");
		function = (int*)tEnviar_NFe_Daruma_load;
	}else if(strcmp(nameFunction, "rLeituraX_NFCe_Daruma") == 0){
    	 if(rLeituraX_NFCe_Daruma_load == NULL) rLeituraX_NFCe_Daruma_load = (rLeituraX_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rLeituraX_NFCe_Daruma");
    		function = (int*)rLeituraX_NFCe_Daruma_load;		
    }else if(strcmp(nameFunction, "rRecuperarXML_NFCe_Daruma") == 0){
		if(rRecuperarXML_NFCe_Daruma_load == NULL) rRecuperarXML_NFCe_Daruma_load = (rRecuperarXML_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rRecuperarXML_NFCe_Daruma");
		function = (int*)rRecuperarXML_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rRetornarInformacao_NFCe_Daruma") == 0){
		if(rRetornarInformacao_NFCe_Daruma_load == NULL) rRetornarInformacao_NFCe_Daruma_load = (rRetornarInformacao_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rRetornarInformacao_NFCe_Daruma");
		function = (int*)rRetornarInformacao_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rRetornarInformacaoArq_NFCe_Daruma") == 0){
		if(rRetornarInformacaoArq_NFCe_Daruma_load == NULL) rRetornarInformacaoArq_NFCe_Daruma_load = (rRetornarInformacaoArq_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rRetornarInformacaoArq_NFCe_Daruma");
		function = (int*)rRetornarInformacaoArq_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rURLQrcode_NFCe_Daruma") == 0){
		if(rURLQrcode_NFCe_Daruma_load == NULL) rURLQrcode_NFCe_Daruma_load = (rURLQrcode_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rURLQrcode_NFCe_Daruma");
		function = (int*)rURLQrcode_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rAvisoErro_NFCe_Daruma") == 0){
		if(rAvisoErro_NFCe_Daruma_load == NULL) rAvisoErro_NFCe_Daruma_load = (rAvisoErro_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rAvisoErro_NFCe_Daruma");
		function = (int*)rAvisoErro_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rInfoEstendida_NFCe_Daruma") == 0){
		if(rInfoEstendida_NFCe_Daruma_load == NULL) rInfoEstendida_NFCe_Daruma_load = (rInfoEstendida_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rInfoEstendida_NFCe_Daruma");
		function = (int*)rInfoEstendida_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rStatusImpressora_NFCe_Daruma") == 0){
		if(rStatusImpressora_NFCe_Daruma_load == NULL) rStatusImpressora_NFCe_Daruma_load = (rStatusImpressora_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rStatusImpressora_NFCe_Daruma");
		function = (int*)rStatusImpressora_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rValidadeCertificado_NFCe_Daruma") == 0){
		if(rValidadeCertificado_NFCe_Daruma_load == NULL) rValidadeCertificado_NFCe_Daruma_load = (rValidadeCertificado_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rValidadeCertificado_NFCe_Daruma");
		function = (int*)rValidadeCertificado_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rCFVerificarStatus_NFCe_Daruma") == 0){
		if(rCFVerificarStatus_NFCe_Daruma_load == NULL) rCFVerificarStatus_NFCe_Daruma_load = (rCFVerificarStatus_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rCFVerificarStatus_NFCe_Daruma");
		function = (int*)rCFVerificarStatus_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rStatusWS_NFCe_Daruma") == 0){
		if(rStatusWS_NFCe_Daruma_load == NULL) rStatusWS_NFCe_Daruma_load = (rStatusWS_NFCe_Daruma_type)GetProcAddress((HMODULE) dynamicLibrary, "rStatusWS_NFCe_Daruma");
		function = (int*)rStatusWS_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "eBuscarPortaVelocidade_DUAL_DarumaFramework") == 0){
		if(eBuscarPortaVelocidade_DUAL_DarumaFramework_load == NULL) eBuscarPortaVelocidade_DUAL_DarumaFramework_load = (eBuscarPortaVelocidade_DUAL_DarumaFramework_type)GetProcAddress((HMODULE) dynamicLibrary, "eBuscarPortaVelocidade_DUAL_DarumaFramework");
		function = (int*)eBuscarPortaVelocidade_DUAL_DarumaFramework_load;
	}else if(strcmp(nameFunction, "iImprimirTexto_DUAL_DarumaFramework") == 0){
		if(iImprimirTexto_DUAL_DarumaFramework_load == NULL) iImprimirTexto_DUAL_DarumaFramework_load = (iImprimirTexto_DUAL_DarumaFramework_type)GetProcAddress((HMODULE) dynamicLibrary, "iImprimirTexto_DUAL_DarumaFramework");
		function = (int*)iImprimirTexto_DUAL_DarumaFramework_load;
	}
#else
	if(strcmp(nameFunction, "regAlterarValor_NFCe_Daruma") == 0){
		if(regAlterarValor_NFCe_Daruma_load == NULL) regAlterarValor_NFCe_Daruma_load = (regAlterarValor_NFCe_Daruma_type)dlsym(dynamicLibrary, "regAlterarValor_NFCe_Daruma");
		function = (int*)regAlterarValor_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "regRetornarValor_NFCe_Daruma") == 0){
		if(regRetornarValor_NFCe_Daruma_load == NULL) regRetornarValor_NFCe_Daruma_load = (regRetornarValor_NFCe_Daruma_type)dlsym(dynamicLibrary, "regRetornarValor_NFCe_Daruma");
		function = (int*)regRetornarValor_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "regAlterarValor_Daruma") == 0){
		if(regAlterarValor_Daruma_load == NULL) regAlterarValor_Daruma_load = (regAlterarValor_Daruma_type)dlsym(dynamicLibrary, "regAlterarValor_Daruma");
		function = (int*)regAlterarValor_Daruma_load;
	}else if(strcmp(nameFunction, "aCFAbrir_NFCe_Daruma") == 0){
		if(aCFAbrir_NFCe_Daruma_load == NULL) aCFAbrir_NFCe_Daruma_load = (aCFAbrir_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFAbrir_NFCe_Daruma");
		function = (int*)aCFAbrir_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFAbrirNumSerie_NFCe_Daruma") == 0){
		if(aCFAbrirNumSerie_NFCe_Daruma_load == NULL) aCFAbrirNumSerie_NFCe_Daruma_load = (aCFAbrirNumSerie_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFAbrirNumSerie_NFCe_Daruma");
		function = (int*)aCFAbrirNumSerie_NFCe_Daruma_load;
    }else if(strcmp(nameFunction, "aCFConfImposto_NFCe_Daruma") == 0){
		if(aCFConfImposto_NFCe_Daruma_load == NULL) aCFConfImposto_NFCe_Daruma_load = (aCFConfImposto_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfImposto_NFCe_Daruma");
		function = (int*)aCFConfImposto_NFCe_Daruma_load;
    }else if(strcmp(nameFunction, "aCFConfRastro_NFCe_Daruma") == 0){
		if(aCFConfRastro_NFCe_Daruma_load == NULL) aCFConfRastro_NFCe_Daruma_load = (aCFConfRastro_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfRastro_NFCe_Daruma");
		function = (int*)aCFConfRastro_NFCe_Daruma_load;
    }else if(strcmp(nameFunction, "aCFConfICMS00_NFCe_Daruma") == 0){
		if(aCFConfICMS00_NFCe_Daruma_load == NULL) aCFConfICMS00_NFCe_Daruma_load = (aCFConfICMS00_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfICMS00_NFCe_Daruma");
		function = (int*)aCFConfICMS00_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMS20_NFCe_Daruma") == 0){
		if(aCFConfICMS20_NFCe_Daruma_load == NULL) aCFConfICMS20_NFCe_Daruma_load = (aCFConfICMS20_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfICMS20_NFCe_Daruma");
		function = (int*)aCFConfICMS20_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMS40_NFCe_Daruma") == 0){
		if(aCFConfICMS40_NFCe_Daruma_load == NULL) aCFConfICMS40_NFCe_Daruma_load = (aCFConfICMS40_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfICMS40_NFCe_Daruma");
		function = (int*)aCFConfICMS40_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMS60_NFCe_Daruma") == 0){
		if(aCFConfICMS60_NFCe_Daruma_load == NULL) aCFConfICMS60_NFCe_Daruma_load = (aCFConfICMS60_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfICMS60_NFCe_Daruma");
		function = (int*)aCFConfICMS60_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMS90_NFCe_Daruma") == 0){
		if(aCFConfICMS90_NFCe_Daruma_load == NULL) aCFConfICMS90_NFCe_Daruma_load = (aCFConfICMS90_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfICMS90_NFCe_Daruma");
		function = (int*)aCFConfICMS90_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMSSN102_NFCe_Daruma") == 0){
		if(aCFConfICMSSN102_NFCe_Daruma_load == NULL) aCFConfICMSSN102_NFCe_Daruma_load = (aCFConfICMSSN102_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfICMSSN102_NFCe_Daruma");
		function = (int*)aCFConfICMSSN102_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMSSN500_NFCe_Daruma") == 0){
		if(aCFConfICMSSN500_NFCe_Daruma_load == NULL) aCFConfICMSSN500_NFCe_Daruma_load = (aCFConfICMSSN500_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfICMSSN500_NFCe_Daruma");
		function = (int*)aCFConfICMSSN500_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfICMSSN900_NFCe_Daruma") == 0){
		if(aCFConfICMSSN900_NFCe_Daruma_load == NULL) aCFConfICMSSN900_NFCe_Daruma_load = (aCFConfICMSSN900_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfICMSSN900_NFCe_Daruma");
		function = (int*)aCFConfICMSSN900_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfPisAliq_NFCe_Daruma") == 0){
		if(aCFConfPisAliq_NFCe_Daruma_load == NULL) aCFConfPisAliq_NFCe_Daruma_load = (aCFConfPisAliq_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfPisAliq_NFCe_Daruma");
		function = (int*)aCFConfPisAliq_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfPisQtde_NFCe_Daruma") == 0){
		if(aCFConfPisQtde_NFCe_Daruma_load == NULL) aCFConfPisQtde_NFCe_Daruma_load = (aCFConfPisQtde_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfPisQtde_NFCe_Daruma");
		function = (int*)aCFConfPisQtde_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfPisNT_NFCe_Daruma") == 0){
		if(aCFConfPisNT_NFCe_Daruma_load == NULL) aCFConfPisNT_NFCe_Daruma_load = (aCFConfPisNT_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfPisNT_NFCe_Daruma");
		function = (int*)aCFConfPisNT_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfPisOutr_NFCe_Daruma") == 0){
		if(aCFConfPisOutr_NFCe_Daruma_load == NULL) aCFConfPisOutr_NFCe_Daruma_load = (aCFConfPisOutr_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfPisOutr_NFCe_Daruma");
		function = (int*)aCFConfPisOutr_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfCofinsAliq_NFCe_Daruma") == 0){
		if(aCFConfCofinsAliq_NFCe_Daruma_load == NULL) aCFConfCofinsAliq_NFCe_Daruma_load = (aCFConfCofinsAliq_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfCofinsAliq_NFCe_Daruma");
		function = (int*)aCFConfCofinsAliq_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfCofinsQtde_NFCe_Daruma") == 0){
		if(aCFConfCofinsQtde_NFCe_Daruma_load == NULL) aCFConfCofinsQtde_NFCe_Daruma_load = (aCFConfCofinsQtde_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfCofinsQtde_NFCe_Daruma");
		function =(int*) aCFConfCofinsQtde_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfCofinsNT_NFCe_Daruma") == 0){
		if(aCFConfCofinsNT_NFCe_Daruma_load == NULL) aCFConfCofinsNT_NFCe_Daruma_load = (aCFConfCofinsNT_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfCofinsNT_NFCe_Daruma");
		function = (int*)aCFConfCofinsNT_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfCofinsOutr_NFCe_Daruma") == 0){
		if(aCFConfCofinsOutr_NFCe_Daruma_load == NULL) aCFConfCofinsOutr_NFCe_Daruma_load = (aCFConfCofinsOutr_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfCofinsOutr_NFCe_Daruma");
		function = (int*)aCFConfCofinsOutr_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFValorLeiImposto_NFCe_Daruma") == 0){
		if(aCFValorLeiImposto_NFCe_Daruma_load == NULL) aCFValorLeiImposto_NFCe_Daruma_load = (aCFValorLeiImposto_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFValorLeiImposto_NFCe_Daruma");
		function = (int*)aCFValorLeiImposto_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFConfLeiImposto_NFCe_Daruma") == 0){
		 if(aCFConfLeiImposto_NFCe_Daruma_load == NULL) aCFConfLeiImposto_NFCe_Daruma_load = (aCFConfLeiImposto_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfLeiImposto_NFCe_Daruma");
			function = (int*)aCFConfLeiImposto_NFCe_Daruma_load;
    }else if(strcmp(nameFunction, "aCFConfCombustivel_NFCe_Daruma") == 0){
		if(aCFConfCombustivel_NFCe_Daruma_load == NULL) aCFConfCombustivel_NFCe_Daruma_load = (aCFConfCombustivel_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFConfCombustivel_NFCe_Daruma");
		function = (int*)aCFConfCombustivel_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFVender_NFCe_Daruma") == 0){
		if(aCFVender_NFCe_Daruma_load == NULL) aCFVender_NFCe_Daruma_load = (aCFVender_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFVender_NFCe_Daruma");
		function = (int*)aCFVender_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFVenderCompleto_NFCe_Daruma") == 0){
		if(aCFVenderCompleto_NFCe_Daruma_load == NULL) aCFVenderCompleto_NFCe_Daruma_load = (aCFVenderCompleto_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFVenderCompleto_NFCe_Daruma");
		function = (int*)aCFVenderCompleto_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFVenderXml_NFCe_Daruma") == 0){
		if(aCFVenderXml_NFCe_Daruma_load == NULL) aCFVenderXml_NFCe_Daruma_load = (aCFVenderXml_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFVenderXml_NFCe_Daruma");
		function = (int*)aCFVenderXml_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFLancarAcrescimoItem_NFCe_Daruma") == 0){
		if(aCFLancarAcrescimoItem_NFCe_Daruma_load == NULL) aCFLancarAcrescimoItem_NFCe_Daruma_load = (aCFLancarAcrescimoItem_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFLancarAcrescimoItem_NFCe_Daruma");
		function = (int*)aCFLancarAcrescimoItem_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFLancarDescontoItem_NFCe_Daruma") == 0){
		if(aCFLancarDescontoItem_NFCe_Daruma_load == NULL) aCFLancarDescontoItem_NFCe_Daruma_load = (aCFLancarDescontoItem_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFLancarDescontoItem_NFCe_Daruma");
		function = (int*)aCFLancarDescontoItem_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFCancelarAcrescimoItem_NFCe_Daruma") == 0){
		if(aCFCancelarAcrescimoItem_NFCe_Daruma_load == NULL) aCFCancelarAcrescimoItem_NFCe_Daruma_load = (aCFCancelarAcrescimoItem_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFCancelarAcrescimoItem_NFCe_Daruma");
		function = (int*)aCFCancelarAcrescimoItem_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFCancelarDescontoItem_NFCe_Daruma") == 0){
		if(aCFCancelarDescontoItem_NFCe_Daruma_load == NULL) aCFCancelarDescontoItem_NFCe_Daruma_load = (aCFCancelarDescontoItem_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFCancelarDescontoItem_NFCe_Daruma");
		function = (int*)aCFCancelarDescontoItem_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFCancelarItemParcial_NFCe_Daruma") == 0){
		if(aCFCancelarItemParcial_NFCe_Daruma_load == NULL) aCFCancelarItemParcial_NFCe_Daruma_load = (aCFCancelarItemParcial_NFCe_Daruma_type)dlsym( dynamicLibrary, "aCFCancelarItemParcial_NFCe_Daruma");
		function = (int*)aCFCancelarItemParcial_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFCancelarItem_NFCe_Daruma") == 0){
		if(aCFCancelarItem_NFCe_Daruma_load == NULL) aCFCancelarItem_NFCe_Daruma_load = (aCFCancelarItem_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFCancelarItem_NFCe_Daruma");
		function = (int*)aCFCancelarItem_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFTotalizar_NFCe_Daruma") == 0){
		if(aCFTotalizar_NFCe_Daruma_load == NULL) aCFTotalizar_NFCe_Daruma_load = (aCFTotalizar_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFTotalizar_NFCe_Daruma");
		function = (int*)aCFTotalizar_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFIdentificarCartao_NFCe_Daruma") == 0){
		if(aCFIdentificarCartao_NFCe_Daruma_load == NULL) aCFIdentificarCartao_NFCe_Daruma_load = (aCFIdentificarCartao_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFIdentificarCartao_NFCe_Daruma");
		function = (int*)aCFIdentificarCartao_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFEfetuarPagamento_NFCe_Daruma") == 0){
		if(aCFEfetuarPagamento_NFCe_Daruma_load == NULL) aCFEfetuarPagamento_NFCe_Daruma_load = (aCFEfetuarPagamento_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFEfetuarPagamento_NFCe_Daruma");
		function = (int*)aCFEfetuarPagamento_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFEfetuarPagamentoCartao_NFCe_Daruma") == 0){
		if(aCFEfetuarPagamentoCartao_NFCe_Daruma_load == NULL) aCFEfetuarPagamentoCartao_NFCe_Daruma_load = (aCFEfetuarPagamentoCartao_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFEfetuarPagamentoCartao_NFCe_Daruma");
		function = (int*)aCFEfetuarPagamentoCartao_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFEstornarPagamento_NFCe_Daruma") == 0){
		if(aCFEstornarPagamento_NFCe_Daruma_load == NULL) aCFEstornarPagamento_NFCe_Daruma_load = (aCFEstornarPagamento_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFEstornarPagamento_NFCe_Daruma");
		function = (int*)aCFEstornarPagamento_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFIdentificarConsumidor_NFCe_Daruma") == 0){
		if(aCFIdentificarConsumidor_NFCe_Daruma_load == NULL) aCFIdentificarConsumidor_NFCe_Daruma_load = (aCFIdentificarConsumidor_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFIdentificarConsumidor_NFCe_Daruma");
		function = (int*)aCFIdentificarConsumidor_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFIdentificarTransportadora_NFCe_Daruma") == 0){
		if(aCFIdentificarTransportadora_NFCe_Daruma_load == NULL) aCFIdentificarTransportadora_NFCe_Daruma_load = (aCFIdentificarTransportadora_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFIdentificarTransportadora_NFCe_Daruma");
		function = (int*)aCFIdentificarTransportadora_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "aCFMsgPromocional_NFCe_Daruma")==0){
		if(aCFMsgPromocional_NFCe_Daruma_load == NULL) aCFMsgPromocional_NFCe_Daruma_load = (aCFMsgPromocional_NFCe_Daruma_type)dlsym(dynamicLibrary, "aCFMsgPromocional_NFCe_Daruma");
		function = (int*)aCFMsgPromocional_NFCe_Daruma_load;
    }else if(strcmp(nameFunction, "tCFEncerrar_NFCe_Daruma") == 0){
		if(tCFEncerrar_NFCe_Daruma_load == NULL) tCFEncerrar_NFCe_Daruma_load = (tCFEncerrar_NFCe_Daruma_type)dlsym(dynamicLibrary, "tCFEncerrar_NFCe_Daruma");
		function = (int*)tCFEncerrar_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tCFEncerrarConfigMsg_NFCe_Daruma") == 0){
		if(tCFEncerrarConfigMsg_NFCe_Daruma_load == NULL) tCFEncerrarConfigMsg_NFCe_Daruma_load = (tCFEncerrarConfigMsg_NFCe_Daruma_type)dlsym(dynamicLibrary, "tCFEncerrarConfigMsg_NFCe_Daruma");
		function = (int*)tCFEncerrarConfigMsg_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tCFCancelar_NFCe_Daruma") == 0){
		if(tCFCancelar_NFCe_Daruma_load == NULL) tCFCancelar_NFCe_Daruma_load = (tCFCancelar_NFCe_Daruma_type)dlsym(dynamicLibrary, "tCFCancelar_NFCe_Daruma");
		function = (int*)tCFCancelar_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tCFCancelarParametrizado_NFCe_Daruma") == 0){
		if(tCFCancelarParametrizado_NFCe_Daruma_load == NULL) tCFCancelarParametrizado_NFCe_Daruma_load = (tCFCancelarParametrizado_NFCe_Daruma_type)dlsym(dynamicLibrary, "tCFCancelarParametrizado_NFCe_Daruma");
		function = (int*)tCFCancelarParametrizado_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tCFInutilizar_NFCe_Daruma") == 0){
		if(tCFInutilizar_NFCe_Daruma_load == NULL) tCFInutilizar_NFCe_Daruma_load = (tCFInutilizar_NFCe_Daruma_type)dlsym(dynamicLibrary, "tCFInutilizar_NFCe_Daruma");
		function = (int*)tCFInutilizar_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tDescartarNota_NFCe_Daruma") == 0){
		if(tDescartarNota_NFCe_Daruma_load == NULL) tDescartarNota_NFCe_Daruma_load = (tDescartarNota_NFCe_Daruma_type)dlsym(dynamicLibrary, "tDescartarNota_NFCe_Daruma");
		function = (int*)tDescartarNota_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "iCFImprimir_NFCe_Daruma") == 0){
		if(iCFImprimir_NFCe_Daruma_load == NULL) iCFImprimir_NFCe_Daruma_load = (iCFImprimir_NFCe_Daruma_type)dlsym(dynamicLibrary, "iCFImprimir_NFCe_Daruma");
		function = (int*)iCFImprimir_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "iCFImprimirParametrizado_NFCe_Daruma") == 0){
		if(iCFImprimirParametrizado_NFCe_Daruma_load == NULL) iCFImprimirParametrizado_NFCe_Daruma_load = (iCFImprimirParametrizado_NFCe_Daruma_type)dlsym(dynamicLibrary, "iCFImprimirParametrizado_NFCe_Daruma");
		function = (int*)iCFImprimirParametrizado_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "iCFReImprimir_NFCe_Daruma") == 0){
		if(iCFReImprimir_NFCe_Daruma_load == NULL) iCFReImprimir_NFCe_Daruma_load = (iCFReImprimir_NFCe_Daruma_type)dlsym(dynamicLibrary, "iCFReImprimir_NFCe_Daruma");
		function = (int*)iCFReImprimir_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "iTEFImprimirResposta_NFCe_Daruma") == 0){
		if(iTEFImprimirResposta_NFCe_Daruma_load == NULL) iTEFImprimirResposta_NFCe_Daruma_load = (iTEFImprimirResposta_NFCe_Daruma_type)dlsym(dynamicLibrary, "iTEFImprimirResposta_NFCe_Daruma");
		function = (int*)iTEFImprimirResposta_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "eAtualizarEnviarXML_NFCe_Daruma") == 0){
		if(eAtualizarEnviarXML_NFCe_Daruma_load == NULL) eAtualizarEnviarXML_NFCe_Daruma_load = (eAtualizarEnviarXML_NFCe_Daruma_type)dlsym(dynamicLibrary, "eAtualizarEnviarXML_NFCe_Daruma");
		function = (int*)eAtualizarEnviarXML_NFCe_Daruma_load;
	}else if (strcmp(nameFunction, "eEmiteOffline_NFCe_Daruma") == 0){
		if(eEmiteOffline_NFCe_Daruma_load == NULL) eEmiteOffline_NFCe_Daruma_load = (eEmiteOffline_NFCe_Daruma_type)dlsym(dynamicLibrary, "eEmiteOffline_NFCe_Daruma");
		function = (int*)eEmiteOffline_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "eAjustarDataHora_NFCe_Daruma") == 0){
		if(eAjustarDataHora_NFCe_Daruma_load == NULL) eAjustarDataHora_NFCe_Daruma_load = (eAjustarDataHora_NFCe_Daruma_type)dlsym(dynamicLibrary, "eAjustarDataHora_NFCe_Daruma");
		function = (int*)eAjustarDataHora_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tCFCancelarOffline_NFCe_Daruma") == 0){
		if(tCFCancelarOffline_NFCe_Daruma_load == NULL) tCFCancelarOffline_NFCe_Daruma_load = (tCFCancelarOffline_NFCe_Daruma_type)dlsym(dynamicLibrary, "tCFCancelarOffline_NFCe_Daruma");
		function = (int*)tCFCancelarOffline_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tEnviarContingenciaOffline_NFCe_Daruma") == 0){
		if(tEnviarContingenciaOffline_NFCe_Daruma_load == NULL) tEnviarContingenciaOffline_NFCe_Daruma_load = (tEnviarContingenciaOffline_NFCe_Daruma_type)dlsym(dynamicLibrary, "tEnviarContingenciaOffline_NFCe_Daruma");
		function = (int*)tEnviarContingenciaOffline_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tEnviarContingenciaCancOffline_NFCe_Daruma") == 0){
		if(tEnviarContingenciaCancOffline_NFCe_Daruma_load == NULL) tEnviarContingenciaCancOffline_NFCe_Daruma_load = (tEnviarContingenciaCancOffline_NFCe_Daruma_type)dlsym(dynamicLibrary, "tEnviarContingenciaCancOffline_NFCe_Daruma");
		function = (int*)tEnviarContingenciaCancOffline_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rNumDocsContingencia_NFCe_Daruma") == 0){
		if(rNumDocsContingencia_NFCe_Daruma_load == NULL) rNumDocsContingencia_NFCe_Daruma_load = (rNumDocsContingencia_NFCe_Daruma_type)dlsym(dynamicLibrary, "rNumDocsContingencia_NFCe_Daruma");
		function = (int*)rNumDocsContingencia_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rNumDocsContingenciaCanc_NFCe_Daruma") == 0){
		if(rNumDocsContingenciaCanc_NFCe_Daruma_load == NULL) rNumDocsContingenciaCanc_NFCe_Daruma_load = (rNumDocsContingenciaCanc_NFCe_Daruma_type)dlsym(dynamicLibrary, "rNumDocsContingenciaCanc_NFCe_Daruma");
		function = (int*)rNumDocsContingenciaCanc_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rRetornarInformacaoContingencia_NFCe_Daruma") == 0){
		if(rRetornarInformacaoContingencia_NFCe_Daruma_load == NULL) rRetornarInformacaoContingencia_NFCe_Daruma_load = (rRetornarInformacaoContingencia_NFCe_Daruma_type)dlsym(dynamicLibrary, "rRetornarInformacaoContingencia_NFCe_Daruma");
		function = (int*)rRetornarInformacaoContingencia_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tEnvioUnitContingenciaOffline_NFCe_Daruma") == 0){
		if(tEnvioUnitContingenciaOffline_NFCe_Daruma_load == NULL) tEnvioUnitContingenciaOffline_NFCe_Daruma_load = (tEnvioUnitContingenciaOffline_NFCe_Daruma_type)dlsym(dynamicLibrary, "tEnvioUnitContingenciaOffline_NFCe_Daruma");
		function = (int*)tEnvioUnitContingenciaOffline_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tEnvioUnitContingenciaCancOffline_NFCe_Daruma") == 0){
		if(tEnvioUnitContingenciaCancOffline_NFCe_Daruma_load == NULL) tEnvioUnitContingenciaCancOffline_NFCe_Daruma_load = (tEnvioUnitContingenciaCancOffline_NFCe_Daruma_type)dlsym(dynamicLibrary, "tEnvioUnitContingenciaCancOffline_NFCe_Daruma");
		function = (int*)tEnvioUnitContingenciaCancOffline_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rUltimaCtg_NFCe_Daruma") == 0){
		if(rUltimaCtg_NFCe_Daruma_load == NULL) rUltimaCtg_NFCe_Daruma_load = (rUltimaCtg_NFCe_Daruma_type)dlsym(dynamicLibrary, "rUltimaCtg_NFCe_Daruma");
		function = (int*)rUltimaCtg_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tEnvioUnitCtg_NFCe_Daruma") == 0){
		if(tEnvioUnitCtg_NFCe_Daruma_load == NULL) tEnvioUnitCtg_NFCe_Daruma_load = (tEnvioUnitCtg_NFCe_Daruma_type)dlsym(dynamicLibrary, "tEnvioUnitCtg_NFCe_Daruma");
		function = (int*)tEnvioUnitCtg_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tTransacaoAdministrativaTEF_NFCe_Daruma") == 0){
		if(tTransacaoAdministrativaTEF_NFCe_Daruma_load == NULL) tTransacaoAdministrativaTEF_NFCe_Daruma_load = (tTransacaoAdministrativaTEF_NFCe_Daruma_type)dlsym(dynamicLibrary, "tTransacaoAdministrativaTEF_NFCe_Daruma");
		function = (int*)tTransacaoAdministrativaTEF_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tTransacaoCancelamentoTEF_NFCe_Daruma") == 0){
		if(tTransacaoCancelamentoTEF_NFCe_Daruma_load == NULL) tTransacaoCancelamentoTEF_NFCe_Daruma_load = (tTransacaoCancelamentoTEF_NFCe_Daruma_type)dlsym(dynamicLibrary, "tTransacaoCancelamentoTEF_NFCe_Daruma");
		function = (int*)tTransacaoCancelamentoTEF_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "tEnviar_NFe_Daruma") == 0){
    	 if(tEnviar_NFe_Daruma_load == NULL) tEnviar_NFe_Daruma_load = (tEnviar_NFe_Daruma_type)dlsym(dynamicLibrary, "tEnviar_NFe_Daruma");
    		function = (int*)tEnviar_NFe_Daruma_load;
	}else if(strcmp(nameFunction, "rLeituraX_NFCe_Daruma") == 0){
    	 if(rLeituraX_NFCe_Daruma_load == NULL) rLeituraX_NFCe_Daruma_load = (rLeituraX_NFCe_Daruma_type)dlsym(dynamicLibrary, "rLeituraX_NFCe_Daruma");
    		function = (int*)rLeituraX_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rRecuperarXML_NFCe_Daruma") == 0){
		if(rRecuperarXML_NFCe_Daruma_load == NULL) rRecuperarXML_NFCe_Daruma_load = (rRecuperarXML_NFCe_Daruma_type)dlsym(dynamicLibrary, "rRecuperarXML_NFCe_Daruma");
		function = (int*)rRecuperarXML_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rRetornarInformacao_NFCe_Daruma") == 0){
		if(rRetornarInformacao_NFCe_Daruma_load == NULL) rRetornarInformacao_NFCe_Daruma_load = (rRetornarInformacao_NFCe_Daruma_type)dlsym (dynamicLibrary, "rRetornarInformacao_NFCe_Daruma");
		function = (int*)rRetornarInformacao_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rRetornarInformacaoArq_NFCe_Daruma") == 0){
		if(rRetornarInformacaoArq_NFCe_Daruma_load == NULL) rRetornarInformacaoArq_NFCe_Daruma_load = (rRetornarInformacaoArq_NFCe_Daruma_type)dlsym (dynamicLibrary, "rRetornarInformacaoArq_NFCe_Daruma");
		function = (int*)rRetornarInformacaoArq_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rURLQrcode_NFCe_Daruma") == 0){
		if(rURLQrcode_NFCe_Daruma_load == NULL) rURLQrcode_NFCe_Daruma_load = (rURLQrcode_NFCe_Daruma_type)dlsym(dynamicLibrary, "rURLQrcode_NFCe_Daruma");
		function = (int*)rURLQrcode_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rAvisoErro_NFCe_Daruma") == 0){
        if(rAvisoErro_NFCe_Daruma_load == NULL) rAvisoErro_NFCe_Daruma_load = (rAvisoErro_NFCe_Daruma_type)dlsym(dynamicLibrary, "rAvisoErro_NFCe_Daruma");
        function = (int*)rAvisoErro_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rInfoEstendida_NFCe_Daruma") == 0){
		if(rInfoEstendida_NFCe_Daruma_load == NULL) rInfoEstendida_NFCe_Daruma_load = (rInfoEstendida_NFCe_Daruma_type)dlsym(dynamicLibrary, "rInfoEstendida_NFCe_Daruma");
		function = (int*)rInfoEstendida_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rStatusImpressora_NFCe_Daruma") == 0){
		if(rStatusImpressora_NFCe_Daruma_load == NULL) rStatusImpressora_NFCe_Daruma_load = (rStatusImpressora_NFCe_Daruma_type)dlsym(dynamicLibrary, "rStatusImpressora_NFCe_Daruma");
		function = (int*)rStatusImpressora_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rValidadeCertificado_NFCe_Daruma") == 0){
		if(rValidadeCertificado_NFCe_Daruma_load == NULL) rValidadeCertificado_NFCe_Daruma_load = (rValidadeCertificado_NFCe_Daruma_type)dlsym(dynamicLibrary, "rValidadeCertificado_NFCe_Daruma");
		function = (int*)rValidadeCertificado_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "rCFVerificarStatus_NFCe_Daruma") == 0){
		if(rCFVerificarStatus_NFCe_Daruma_load == NULL) rCFVerificarStatus_NFCe_Daruma_load = (rCFVerificarStatus_NFCe_Daruma_type)dlsym(dynamicLibrary, "rCFVerificarStatus_NFCe_Daruma");
		function = (int*)rCFVerificarStatus_NFCe_Daruma_load;
    }else if(strcmp(nameFunction, "rStatusWS_NFCe_Daruma") == 0){
		if(rStatusWS_NFCe_Daruma_load == NULL) rStatusWS_NFCe_Daruma_load = (rStatusWS_NFCe_Daruma_type)dlsym(dynamicLibrary, "rStatusWS_NFCe_Daruma");
		function = (int*)rStatusWS_NFCe_Daruma_load;
	}else if(strcmp(nameFunction, "eBuscarPortaVelocidade_DUAL_DarumaFramework") == 0){
		if(eBuscarPortaVelocidade_DUAL_DarumaFramework_load == NULL) eBuscarPortaVelocidade_DUAL_DarumaFramework_load = (eBuscarPortaVelocidade_DUAL_DarumaFramework_type)dlsym(dynamicLibrary, "eBuscarPortaVelocidade_DUAL_DarumaFramework");
		function = (int*)eBuscarPortaVelocidade_DUAL_DarumaFramework_load;
	}else if(strcmp(nameFunction, "iImprimirTexto_DUAL_DarumaFramework") == 0){
		if(iImprimirTexto_DUAL_DarumaFramework_load == NULL) iImprimirTexto_DUAL_DarumaFramework_load = (iImprimirTexto_DUAL_DarumaFramework_type)dlsym(dynamicLibrary, "iImprimirTexto_DUAL_DarumaFramework");
		function = (int*)iImprimirTexto_DUAL_DarumaFramework_load;
	}
#endif

	if (!function) 
	{
#ifdef WIN32
		error = (char*) GetLastError();
#else
		error = dlerror();
#endif
		printf("error ao carregar a funcao %s: %s\n", nameFunction, error);
	}

	return function;
}